@@ -3,6 +3,7 @@ package main
 import . "swigtests/typemap_out_optimal"
 
 func main() {
-	SetXXDebug(false)
+	SetXXTrace(false)
 	_ = XXCreate()
+	_ = XXCreateConst()
 }
