@@ -7,14 +7,14 @@ grouping
 
 x = grouping.test1(42);
 if (x != 42)
-    error
+    error("failed");
 endif
 
 grouping.test2(42);
 
 x = (grouping.do_unary(37, grouping.NEGATE));
 if (x != -37)
-    error
+    error("failed");
 endif
 
 grouping.cvar.test3 = 42;
