@@ -6,5 +6,5 @@ endif
 using1
 
 if (using1.spam(37) != 37)
-    error
+    error("failed");
 endif
