@@ -20,3 +20,7 @@ if special_variable_macros.testJim(name) != "multiname num":
     raise "test failed"
 if special_variable_macros.testJohn(special_variable_macros.PairIntBool(10, False)) != 123:
     raise "test failed"
+if special_variable_macros.makeStringInt("stringint", 999) != "stringint":
+    raise "test failed"
+if special_variable_macros.provideStringInt(999) != "1000":
+    raise "test failed"
